/*
* JBoss, Home of Professional Open Source
* Copyright 2018, Red Hat, Inc. and/or its affiliates, and individual contributors
* by the @authors tag. See the copyright.txt in the distribution for a
* full listing of individual contributors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
* http://www.apache.org/licenses/LICENSE-2.0
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/
package org.hibernate.validator;

import java.security.BasicPermission;

/**
 * Our specific implementation of {@link BasicPermission} as we cannot define additional {@link RuntimePermission}.
 * <p>
 * {@code HibernateValidatorPermission} is thread-safe and immutable.
 *
 * @author Guillaume Smet
 */
public class HibernateValidatorPermission extends BasicPermission {

	public static final HibernateValidatorPermission ACCESS_PRIVATE_MEMBERS = new HibernateValidatorPermission( "accessPrivateMembers" );

	public HibernateValidatorPermission(String name) {
		super( name );
	}

	public HibernateValidatorPermission(String name, String actions) {
		super( name, actions );
	}
}
